==> gnocatan_0.8.1.45.orig.tar.gz: gnocatan-0.8.1.45/client/gtk/gameover.c <==
/* Gnocatan - Implementation of the excellent Settlers of Catan board game.
 *   Go buy a copy.
 *
 * Copyright (C) 1999 the Free Software Foundation
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include "config.h"
#include "frontend.h"

GtkWidget *gameover_create_dlg(gint player_num, gint num_points)
{
	GtkWidget *dlg;
	GtkWidget *dlg_vbox;
	GtkWidget *vbox;
	GtkWidget *lbl;
	char buff[512];

	dlg = gtk_dialog_new_with_buttons(
			_("Game over"),
			GTK_WINDOW(app_window),
			GTK_DIALOG_DESTROY_WITH_PARENT,
			GTK_STOCK_OK, GTK_RESPONSE_OK,
			NULL);
	gtk_widget_realize(dlg);
	gdk_window_set_functions(dlg->window, GDK_FUNC_MOVE | GDK_FUNC_CLOSE);

	dlg_vbox = GTK_DIALOG(dlg)->vbox;
	gtk_widget_show(dlg_vbox);

	vbox = gtk_vbox_new(FALSE, 50);
	gtk_widget_show(vbox);
	gtk_box_pack_start(GTK_BOX(dlg_vbox), vbox, FALSE, TRUE, 0);
	gtk_container_set_border_width(GTK_CONTAINER(vbox), 20);

	sprintf(buff, _("%s has won the game with %d victory points!"),
		player_name(player_num, TRUE), num_points);
	log_message( MSG_INFO, _("%s has won the game with %d victory points!\n"),
		player_name(player_num, TRUE), num_points);
	lbl = gtk_label_new(buff);
	gtk_widget_show(lbl);
	gtk_box_pack_start(GTK_BOX(vbox), lbl, FALSE, TRUE, 0);

	sprintf(buff, _("All praise %s, Lord of All Gnocatan!"),
		player_name(player_num, TRUE));
	lbl = gtk_label_new(buff);
	gtk_widget_show(lbl);
	gtk_box_pack_start(GTK_BOX(vbox), lbl, FALSE, TRUE, 0);

        gtk_widget_show(dlg);
	g_signal_connect(dlg, "response",
			G_CALLBACK(gtk_widget_destroy), NULL);

	return dlg;
}

==> gnocatan_0.8.1.59.orig.tar.gz: gnocatan-0.8.1.59/client/gtk/gameover.c <==
/* Gnocatan - Implementation of the excellent Settlers of Catan board game.
 *   Go buy a copy.
 *
 * Copyright (C) 1999 the Free Software Foundation
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include "config.h"
#include "frontend.h"

GtkWidget *gameover_create_dlg(gint player_num, gint num_points)
{
	GtkWidget *dlg;
	GtkWidget *dlg_vbox;
	GtkWidget *vbox;
	GtkWidget *lbl;
	char buff[512];

	dlg = gtk_dialog_new_with_buttons(_("Game over"),
					  GTK_WINDOW(app_window),
					  GTK_DIALOG_DESTROY_WITH_PARENT,
					  GTK_STOCK_OK, GTK_RESPONSE_OK,
					  NULL);
	gtk_widget_realize(dlg);
	gdk_window_set_functions(dlg->window,
				 GDK_FUNC_MOVE | GDK_FUNC_CLOSE);

	dlg_vbox = GTK_DIALOG(dlg)->vbox;
	gtk_widget_show(dlg_vbox);

	vbox = gtk_vbox_new(FALSE, 50);
	gtk_widget_show(vbox);
	gtk_box_pack_start(GTK_BOX(dlg_vbox), vbox, FALSE, TRUE, 0);
	gtk_container_set_border_width(GTK_CONTAINER(vbox), 20);

	sprintf(buff, _("%s has won the game with %d victory points!"),
		player_name(player_num, TRUE), num_points);
	log_message(MSG_INFO,
		    _("%s has won the game with %d victory points!\n"),
		    player_name(player_num, TRUE), num_points);
	lbl = gtk_label_new(buff);
	gtk_widget_show(lbl);
	gtk_box_pack_start(GTK_BOX(vbox), lbl, FALSE, TRUE, 0);

	sprintf(buff, _("All praise %s, Lord of All Gnocatan!"),
		player_name(player_num, TRUE));
	lbl = gtk_label_new(buff);
	gtk_widget_show(lbl);
	gtk_box_pack_start(GTK_BOX(vbox), lbl, FALSE, TRUE, 0);

	gtk_widget_show(dlg);
	g_signal_connect(dlg, "response",
			 G_CALLBACK(gtk_widget_destroy), NULL);

	return dlg;
}
